## PAVES 0.8.0: Unreleased

- Correct and improve text extraction
- Correct various problems with table detection
- TODO: Add more optional table detectors
- TODO: Add preliminary table structure prediction
- Remove "bears" API that I never used for anything
